/*+++*
 *  title:	CommandKeysBrowserCell.h
 *  abstract:	Interface of CommandKeysBrowserCell class for CommandKeys.preferences.
 *  author:	Tom Hageman <tom@basil.icce.rug.nl>
 *  created:	March 1999
 *  modified:	(see RCS Log at end)
 *  copyright:
 *
 *		Copyright (C) 1999  Tom R. Hageman.
 *
 *	This is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This software is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this software; see the file COPYING.  If not, write to
 *	the Free Software Foundation, 59 Temple Place - Suite 330,
 *	Boston, MA 02111-1307, USA.
 *
 *  description:
 *
 *      This module defines the following classes:
 *      - CommandKeysBrowserCell
 *---*/

#ifdef RCS_CommandKeysBrowserCell_ID
static const char * const RCS_h_id = ((void)&RCS_h_id,
	"@(#)CommandKeysBrowserCell.h,v 1.3 1999/04/12 18:09:15 tom Exp");
#endif

#import <appkit/appkit.h>


@interface CommandKeysBrowserCell : NXBrowserCell
{
    NXAtom owner;		// The name of the application
    HashTable *commandKeyHash;	// a hashtable of CommandKeysItems.
    BOOL nextstep;		// YES if NEXTSTEP default
    BOOL openstep;		// YES if OPENSTEP default (can be both).
}

- initTextCell:(const char *)aString;

- (void)setOwner:(NXAtom)anOwner;
- (NXAtom)owner;

- (void)setCommandKeyHash:(HashTable *)aCommandKeyHash;
- (HashTable *)commandKeyHash;
    /* NB. the cell takes ownership of the hashtable, i.e. it's not copied,
       but it and its contents will be destroyed when the cell is freed,
       or a new hashtable instance is assigned. */

- (void)setCommand:(const char *)aCommand keyEquivalent:(unsigned short)aKeyEquivalent;
    /* Convenience method; add, modify or remove (with keyEquivalent = 0)
       a command-key definition. */

- (void)setNextstep:(BOOL)flag;
- (BOOL)nextstep;
- (void)setOpenstep:(BOOL)flag;
- (BOOL)openstep;

- drawInside:(const NXRect *)cellFrame inView:controlView;

@end // CommandKeysBrowserCell
