/*+++
 *  title:      CommandKeysBrowserCell.m
 *  abstract:   Implementation of CommandKeysBrowserCell class for CommandKeys.preferences.
 *  author:     Tom Hageman <tom@basil.icce.rug.nl>
 *  created:    March 1999
 *  modified:   (see RCS Log at end)
 *  copyleft:
 *
 *		Copyright (C) 1999  Tom R. Hageman.
 *
 *	This is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This software is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this software; see the file COPYING.  If not, write to
 *	the Free Software Foundation, 59 Temple Place - Suite 330,
 *	Boston, MA 02111-1307, USA.
 *
 *  description:
 *      (see corresponding *.h file)
 *---*/

#ifdef RCS_ID
static const char * const RCSid = ((void)&RCSid,
	"@(#)CommandKeysBrowserCell.m,v 1.5 1999/04/17 21:59:18 tom Exp");
#   define RCS_CommandKeysBrowserCell_ID
#endif

#import "CommandKeysBrowserCell.h"

#import "CommandKeysItem.h"


@implementation CommandKeysBrowserCell

- initTextCell:(const char *)aString
{
    self = [super initTextCell:aString];

    if (self)
    {
	// provide default values for ivars.
	///owner = NULL;
	///commandKeyHash = NULL;
	nextstep = YES;
	openstep = YES;
    }
    return self;
}

- free
{
    owner = NULL;
    [self setCommandKeyHash:nil];
    return [super free];
}


- (void)setOwner:(NXAtom)theOwner
{
    [self setStringValueNoCopy:theOwner];
    owner = theOwner;
}

- (NXAtom)owner
{
    if (!owner)
    {
	const char *stringValue = [self stringValue];

	if (stringValue) owner = NXUniqueString(stringValue);
    }
    return owner;
}

- (void)setCommandKeyHash:(HashTable *)aCommandKeyHash
{
    if (commandKeyHash == aCommandKeyHash) return;
    if (commandKeyHash)
    {
	[commandKeyHash freeObjects];
	[commandKeyHash free];
    }
    commandKeyHash = aCommandKeyHash;
}

- (HashTable *)commandKeyHash
{
    return commandKeyHash;
}

- (void)setCommand:(const char *)aCommand keyEquivalent:(unsigned short)aKeyEquivalent
{
    if (aKeyEquivalent == 0)
    {
	if (commandKeyHash)
	{
	    CommandKeysItem *item = [commandKeyHash valueForKey:aCommand];

	    if (item)
	    {
		[commandKeyHash removeKey:aCommand];
		[item free];

		if ([commandKeyHash count] == 0)
		{
		    [self setCommandKeyHash:nil];   // Remove it.
		}
	    }
	}
    }
    else
    {
	NXZone *zone = [self zone];
	CommandKeysItem *item;

	if (commandKeyHash == nil)
	{
	    commandKeyHash = [[HashTable allocFromZone:zone] initKeyDesc:@encode(char *)];
	}

	if ((item = [commandKeyHash valueForKey:aCommand]) == nil)
	{
	    item = [[CommandKeysItem allocFromZone:zone] initWithCommand:aCommand
			keyEquivalent:aKeyEquivalent];
	    [commandKeyHash insertKey:[item command] value:item];
	}
	else
	{
	    [item setKeyEquivalent:aKeyEquivalent];
	}
    }
}

- (void)setNextstep:(BOOL)flag	{ nextstep = flag; }
- (BOOL)nextstep		{ return nextstep; }
- (void)setOpenstep:(BOOL)flag	{ openstep = flag; }
- (BOOL)openstep		{ return openstep; }

- drawInside:(const NXRect *)cellFrame inView:controlView
{
    Font *font = support; //[self font];
    Font *newFont = font;

    // Show cells with commandKey definition in bold font.
    if (commandKeyHash)
    {
	newFont = [[FontManager new] convert:font toHaveTrait:NX_BOLD];
    }
    if (newFont != font)
    {
	[self setFont:newFont];
    }
    [super drawInside:cellFrame inView:controlView];

    if (newFont != font)
    {
	[self setFont:font];
    }

    // Mark OPENSTEP owners.
    if (openstep)
    {
	static TextFieldCell *sharedTextCell;
	NXSize sharedTextCellSize;
	NXRect rect = (*cellFrame);

	//make cell
	if (!sharedTextCell)
	{
	    sharedTextCell = [[TextFieldCell alloc] init];
	    [sharedTextCell setWrap:NO];
	    [sharedTextCell setFont:[self font]];
	    [sharedTextCell setAlignment:NX_RIGHTALIGNED];
	}

	[sharedTextCell setStringValueNoCopy:(nextstep ? "n,o" : "o")];
	[sharedTextCell calcCellSize:&sharedTextCellSize];

	NX_X(&rect) = NX_MAXX(&rect) - sharedTextCellSize.width + 1;
	NX_WIDTH(&rect) = sharedTextCellSize.width;

	PSsetgray((cFlags1.highlighted|cFlags1.state) ? NX_WHITE : NX_LTGRAY);
	NXRectFill(&rect);

	[sharedTextCell drawInside:&rect inView:controlView];	
    }
    return self;
}

@end // CommandKeysBrowserCell
