/*+++
 *  title:      CommandKeysItem.m
 *  abstract:   Implementation of CommandKeysItem class for CommandKeys preferences.
 *  author:     Tom Hageman <tom@basil.icce.rug.nl>
 *  created:    April 1999
 *  modified:   (see RCS Log at end)
 *  copyleft:
 *
 *		Copyright (C) 1999  Tom R. Hageman.
 *
 *	This is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This software is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this software; see the file COPYING.  If not, write to
 *	the Free Software Foundation, 59 Temple Place - Suite 330,
 *	Boston, MA 02111-1307, USA.
 *
 *  description:
 *      (see corresponding *.h file)
 *---*/

#ifdef RCS_ID
static const char * const RCSid = ((void)&RCSid,
	"@(#)CommandKeysItem.m,v 1.2 1999/04/17 18:52:19 tom Exp");
#   define RCS_CommandKeysItem_ID
#endif

#import "CommandKeysItem.h"

#import <objc/hashtable.h>
#import <stdlib.h>


@implementation CommandKeysItem

- initWithCommand:(const char *)aCommand
    keyEquivalent:(unsigned short)aKeyEquivalent
{
    id instance = [super init];

    if (instance == self)
    {
	command = NXCopyStringBufferFromZone(aCommand, [self zone]);
	keyEquivalent = aKeyEquivalent;
    }
    return instance;
}

- free
{
    free((void *)command);
    return [super free];
}

- (const char *)command { return command; }

- (unsigned short)keyEquivalent { return keyEquivalent; }

- (void)setKeyEquivalent:(unsigned short)aKeyEquivalent
{
    keyEquivalent = aKeyEquivalent;
}

- (BOOL)isEqualToCommandKeysItem:(CommandKeysItem *)anItem
{
    if (anItem == self) return YES;
    if (anItem == nil) return NO;

    if (anItem->keyEquivalent != self->keyEquivalent) return NO;

    if (anItem->command == self->command) return YES;
    if (anItem->command == NULL) return NO;
    if (self->command == NULL) return NO;
    if (strcmp(anItem->command, self->command) == 0) return YES;
    return NO;
}

- (BOOL)isEqual:anObject
{
    if (anObject == self) return YES;
    if (anObject == nil) return NO;

    if (![anObject isMemberOf:[self class]]) return NO;

    return [self isEqualToCommandKeysItem:anObject];
}

@end // CommandKeysItem
