/*+++
 *  title:      CommandKeysMenuBrowserCell.m
 *  abstract:   Implementation of CommandKeysMenuBrowserCell class for CommandKeys.preferences.
 *  author:     Tom Hageman <tom@basil.icce.rug.nl>
 *  created:    March 1999
 *  modified:   (see RCS Log at end)
 *  copyleft:
 *
 *		Copyright (C) 1999  Tom R. Hageman.
 *
 *	This is free software; you can redistribute it and/or modify
 *	it under the terms of the GNU General Public License as published by
 *	the Free Software Foundation; either version 2 of the License, or
 *	(at your option) any later version.
 *
 *	This software is distributed in the hope that it will be useful,
 *	but WITHOUT ANY WARRANTY; without even the implied warranty of
 *	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *	GNU General Public License for more details.
 *
 *	You should have received a copy of the GNU General Public License
 *	along with this software; see the file COPYING.  If not, write to
 *	the Free Software Foundation, 59 Temple Place - Suite 330,
 *	Boston, MA 02111-1307, USA.
 *
 *  description:
 *      (see corresponding *.h file)
 *---*/

#ifdef RCS_ID
static const char * const RCSid = ((void)&RCSid,
	"@(#)CommandKeysMenuBrowserCell.m,v 1.2 1999/03/29 19:00:05 tom Exp");
#   define RCS_CommandKeysMenuBrowserCell_ID
#endif

#import "CommandKeysMenuBrowserCell.h"


@implementation CommandKeysMenuBrowserCell

- initTextCell:(const char *)aString
{
    self = [super initTextCell:aString];

    if (self)
    {
	// Provide default values for ivars.
	///keyEquivalent = 0;
    }
    return self;
}

- (void)setKeyEquivalent:(unsigned short)aKeyEquivalent
{
    keyEquivalent = aKeyEquivalent;
}

- (unsigned short)keyEquivalent
{
    return keyEquivalent;
}

- calcCellSize:(NXSize *)theSize inRect:(const NXRect *)aRect
{
    [super calcCellSize:theSize inRect:aRect];
    theSize->height += 4 + 1; // fudge...
    return self;
}

- drawInside:(const NXRect *)cellFrame inView:controlView
{
    NXRect newFrame;

    NXDrawButton(cellFrame, NULL);

    newFrame = *cellFrame;
    NXInsetRect(&newFrame, 2, 2);

    [super drawInside:&newFrame inView:controlView];

    if (keyEquivalent)
    {
	static TextFieldCell *sharedTextCell;
	static NXSize sharedTextCellSize;
	char keybuf[2];
	NXRect keyrect = newFrame;

	//make cell
	if (!sharedTextCell)
	{
	    sharedTextCell = [[TextFieldCell alloc] init];
	    [sharedTextCell setWrap:NO];
	    [sharedTextCell setFont:[self font]];
	    [sharedTextCell setStringValueNoCopy:"M"];
	    [sharedTextCell setAlignment:NX_CENTERED];
	    [sharedTextCell calcCellSize:&sharedTextCellSize];
	}

	keybuf[0] = (char)keyEquivalent;
	keybuf[1] = '\0';
	[sharedTextCell setStringValueNoCopy:keybuf];

	NX_X(&keyrect) = NX_MAXX(&keyrect) - sharedTextCellSize.width + 1;
	NX_WIDTH(&keyrect) = sharedTextCellSize.width;

//	PSsetgray((cFlags1.highlighted|cFlags1.state) ? NX_WHITE : NX_LTGRAY);
//	NXRectFill(&keyrect);

	[sharedTextCell drawInside:&keyrect inView:controlView];	
    }
    return self;
}

@end // CommandKeysMenuBrowserCell
